# -*- coding: utf-8 -*-
from setuphelpers import *

uninstallkey = []

# Declaring specific app values (TO CHANGE)
bin_name = "dotNetFx40_Full_x86_x64.exe"
silent_inst_args = "/q /norestart"


def install():
    package_version = control.version.split("-", 1)[0]
    package_version_split = package_version.split(".")
    short_package_version = "%s.%s" % (package_version_split[0], package_version_split[1])
    # print(short_package_version)

    # Getting the used storage on programfiles before installation (place it on the top)
    get_disk_free_space_before = get_disk_free_space(programfiles)

    # Getting actual .NET Framework 4.x version installed
    try:
        dotnet4_version_installed = registry_readstring(HKEY_LOCAL_MACHINE, "SOFTWARE\\Microsoft\\NET Framework Setup\\NDP\\v4\\Full", "Version")
        print("Actual installed .NET Framework 4 version is " + dotnet4_version_installed)
        dotnet4_version_split = dotnet4_version_installed.split(".")
        short_dotnet4_version = "%s.%s" % (dotnet4_version_split[0], dotnet4_version_split[1])
    except:
        print(".NET Framework 4.x is not currently installed")
        short_dotnet4_version = "0"
    # print(short_dotnet4_version)

    # Installing the package
    if Version(short_dotnet4_version) == Version(short_package_version):
        print(".NET Framework " + short_package_version + " is already installed")
    elif Version(short_dotnet4_version) > Version(short_package_version):
        error(
            'A newer version of the .NET Framework is already installed. Please note that the 4.0 CANNOT be installed in parallel. We recommend that you change the dependency of your affected other packages from "tis-dotnetfx4.0" to "tis-dotnetfx".'
        )
    else:
        install_exe_if_needed(bin_name, silentflags=silent_inst_args)

    # Return used storage of the program. (place it on the bottom)
    get_disk_free_space_after = get_disk_free_space(programfiles)
    free_space_after_diff = get_disk_free_space_before - get_disk_free_space_after
    print("Storage used: " + str(free_space_after_diff))


def uninstall():
    if iswin64():
        run(r"MsiExec.exe /X{8E34682C-8118-31F1-BC4C-98CD9675E1C2} /q /norestart")
        run(r"MsiExec.exe /X{F5B09CFD-F0B2-36AF-8DF4-1DF6B63FC7B4} /q /norestart")
    else:
        run(r"MsiExec.exe /X{0A0CADCF-78DA-33C4-A350-CD51849B9702} /q /norestart")
        run(r"MsiExec.exe /X{3C3901C5-3455-3E0A-A214-0B093A5070A6} /q /norestart")


def audit():
    # Getting actual .NET Framework 4.x version installed
    short_package_version = "4.0"
    dotnet4_version_installed = registry_readstring(HKEY_LOCAL_MACHINE, "SOFTWARE\\Microsoft\\NET Framework Setup\\NDP\\v4\\Full", "Version")
    print("Actual installed .NET Framework 4 version is " + dotnet4_version_installed)
    dotnet4_version_split = dotnet4_version_installed.split(".")
    short_dotnet4_version = "%s.%s" % (dotnet4_version_split[0], dotnet4_version_split[1])

    if short_dotnet4_version > short_package_version:
        print(
            'A newer version of the .NET Framework is already installed. Please note that the 4.0 CANNOT be installed in parallel. We recommend that you change the dependency of your affected other packages from "tis-dotnetfx4.0" to "tis-dotnetfx".'
        )
        return "WARNING"


def update_package():
    proxy = {}
    if isfile(makepath(application_data(), "waptconsole", "waptconsole.ini")):
        proxywapt = inifile_readstring(makepath(user_local_appdata(), "waptconsole", "waptconsole.ini"), "global", "http_proxy")
        if proxywapt:
            proxy = {"http": proxywapt, "https": proxywapt}

    # https://dotnet.microsoft.com/download/dotnet-framework

    url_dl = "https://download.microsoft.com/download/9/5/A/95A9616B-7A37-4AF6-BC36-D6EA96C8DAAE/dotNetFx40_Full_x86_x64.exe"
    print("Download url is: " + url_dl)

    if not isfile(bin_name):
        print("Downloading " + bin_name)
        wget(url_dl, bin_name, proxies=proxy)
